Oriole-Service
==============

.. image:: https://travis-ci.org/zhouxiaoxiang/oriole-service.png?branch=master  
  :target: http://travis-ci.org/zhouxiaoxiang/oriole-service

Rapidly create services.

*[Framework]*

`Orile-Service <https://github.com/zhouxiaoxiang/oriole-service>`_.

* Create a service.

  .. code:: python

  oriole go <name>

  e.g. oriole go log

* Run a service.

  .. code:: python

  oriole run <service>

  e.g. oriole run log

* Run unit tests.

  .. code:: python

  oriole test

* Create documents.

  .. code:: python

  oriole doc
